==> treeland_0.5.20.tar.xz: BUILD/src/plugins/lockscreen/translations/lockscreen.zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Center</name>
    <message>
        <source>Return to default mode</source>
        <translation type="vanished">返回默认模式</translation>
    </message>
    <message>
        <source>Do you want to back to default?</source>
        <translation type="vanished">是否返回默认模式</translation>
    </message>
    <message>
        <source>This action will reboot machine, please confirm.</source>
        <translation type="vanished">此操作将会重启机器，请确认</translation>
    </message>
    <message>
        <source>Back To Default Mode</source>
        <translation type="vanished">回到默认模式</translation>
    </message>
    <message>
        <source>Other Users</source>
        <translation type="vanished">其他用户</translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">电源</translation>
    </message>
</context>
<context>
    <name>ControlAction</name>
    <message>
        <source>Other Users</source>
        <translation type="obsolete">其他用户</translation>
    </message>
    <message>
        <location filename="../qml/ControlAction.qml" line="55"/>
        <source>Power</source>
        <translation type="unfinished">电源</translation>
    </message>
    <message>
        <source>lock</source>
        <translation type="vanished">锁定</translation>
    </message>
</context>
<context>
    <name>Greeter</name>
    <message>
        <source>Password is incorrect.</source>
        <translation type="vanished">密码错误</translation>
    </message>
</context>
<context>
    <name>HintLabel</name>
    <message>
        <location filename="../qml/HintLabel.qml" line="26"/>
        <source>Password Hint</source>
        <translation>密码提示</translation>
    </message>
</context>
<context>
    <name>LockView</name>
    <message>
        <location filename="../qml/LockView.qml" line="176"/>
        <source>Password is incorrect.</source>
        <translation type="unfinished">密码错误</translation>
    </message>
</context>
<context>
    <name>PowerList</name>
    <message>
        <location filename="../qml/PowerList.qml" line="60"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../qml/PowerList.qml" line="50"/>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="vanished">注销</translation>
    </message>
    <message>
        <location filename="../qml/PowerList.qml" line="43"/>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../qml/PowerList.qml" line="36"/>
        <source>Shut Down</source>
        <translation>关机</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="vanished">%1 (Wayland)</translation>
    </message>
</context>
<context>
    <name>ShutdownView</name>
    <message>
        <location filename="../qml/ShutdownView.qml" line="32"/>
        <source>lock</source>
        <translation type="unfinished">锁定</translation>
    </message>
    <message>
        <location filename="../qml/ShutdownView.qml" line="37"/>
        <source>switch user</source>
        <translation type="unfinished">切换帐户</translation>
    </message>
    <message>
        <location filename="../qml/ShutdownView.qml" line="43"/>
        <source>Logout</source>
        <translation type="unfinished">注销</translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <source>Administrator</source>
        <translation type="vanished">管理员</translation>
    </message>
    <message>
        <source>Standard User</source>
        <translation type="vanished">标准用户</translation>
    </message>
</context>
<context>
    <name>UserInput</name>
    <message>
        <location filename="../qml/UserInput.qml" line="15"/>
        <source>Please enter password</source>
        <translation>请输入密码</translation>
    </message>
    <message>
        <location filename="../qml/UserInput.qml" line="141"/>
        <source>Password</source>
        <translation type="unfinished">密码</translation>
    </message>
</context>
</TS>

==> treeland_0.7.3.tar.xz: BUILD/src/plugins/lockscreen/translations/lockscreen.zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>Center</name>
    <message>
        <source>Return to default mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you want to back to default?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This action will reboot machine, please confirm.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back To Default Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">电源</translation>
    </message>
</context>
<context>
    <name>ControlAction</name>
    <message>
        <source>Other Users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/ControlAction.qml" line="55"/>
        <source>Power</source>
        <translation>电源</translation>
    </message>
</context>
<context>
    <name>Greeter</name>
    <message>
        <source>Password is incorrect.</source>
        <translation type="vanished">密码错误</translation>
    </message>
</context>
<context>
    <name>HintLabel</name>
    <message>
        <location filename="../qml/HintLabel.qml" line="26"/>
        <source>Password Hint</source>
        <translation>密码提示</translation>
    </message>
</context>
<context>
    <name>LockView</name>
    <message>
        <location filename="../qml/LockView.qml" line="176"/>
        <source>Password is incorrect.</source>
        <translation>密码错误</translation>
    </message>
</context>
<context>
    <name>PowerList</name>
    <message>
        <location filename="../qml/PowerList.qml" line="60"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../qml/PowerList.qml" line="50"/>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <location filename="../qml/PowerList.qml" line="43"/>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../qml/PowerList.qml" line="36"/>
        <source>Shut Down</source>
        <translation>关机</translation>
    </message>
</context>
<context>
    <name>SessionModel</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownView</name>
    <message>
        <location filename="../qml/ShutdownView.qml" line="32"/>
        <source>lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <location filename="../qml/ShutdownView.qml" line="37"/>
        <source>switch user</source>
        <translation>切换帐户</translation>
    </message>
    <message>
        <location filename="../qml/ShutdownView.qml" line="43"/>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <source>Administrator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Standard User</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UserInput</name>
    <message>
        <location filename="../qml/UserInput.qml" line="15"/>
        <source>Please enter password</source>
        <translation>请输入密码</translation>
    </message>
    <message>
        <location filename="../qml/UserInput.qml" line="141"/>
        <source>Password</source>
        <translation>密码</translation>
    </message>
</context>
</TS>
